% We might also decide to use for loops to investigate images. 

%We are loading a default image stored in matlab. Ordinarily we would have
%to provide the full path to the image, or if it was stored in our
%workspace, use ./filename
image_info = dicominfo('CT-MONO2-16-ankle.dcm'); % gets the header info
my_dicom = dicomread(image_info);
figure, imshow(my_dicom,[]);

% Perhaps we want to find all elements of "my_dicom" that are greater than
% 1000, and replace them with zero (black) 

% initialize a new image that is the same as the old one to start
my_dicom_new = my_dicom; 

% We are going to use a nested for loop here. We loop through every element
% of the first dimension of "my_dicom_new" using "i"
for i = 1:size(my_dicom_new,1)
    % We loop through each element of the second dimension of
    % "my_dicom_new" using "j"
    for j = 1:size(my_dicom_new,2)
        if my_dicom_new(i,j) > 1000 % check if the current element is 
            % larger than 1000
            my_dicom_new(i,j) = 0; % if so, replace it with zero
        end
    end
end
figure, imshow(my_dicom_new,[]);

% However, we could have done this faster without for loops
my_dicom_new2 = my_dicom; 
replacement_inds = find(my_dicom > 1000);
my_dicom_new2(replacement_inds) = 0; 

figure, imshow(my_dicom_new,[]); 

